#!../tree_wish
#
# mkIndex.tcl - generate a tclIndex file in the current directory
# "@(#) $Id: mkIndex.tcl,v 1.1.1.1 1996/02/26 13:10:07 abrighto Exp $"

auto_mkindex . *.tcl
exit 0
